@@ -12,7 +12,6 @@
 #include "opentelemetry/exporters/otlp/otlp_file_metric_exporter_factory.h"
 #include "opentelemetry/exporters/otlp/otlp_file_metric_exporter_options.h"
 #include "opentelemetry/metrics/meter_provider.h"
-#include "opentelemetry/metrics/provider.h"
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_factory.h"
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_options.h"
 #include "opentelemetry/sdk/metrics/meter_context.h"
@@ -20,6 +19,7 @@
 #include "opentelemetry/sdk/metrics/meter_provider.h"
 #include "opentelemetry/sdk/metrics/meter_provider_factory.h"
 #include "opentelemetry/sdk/metrics/metric_reader.h"
+#include "opentelemetry/sdk/metrics/provider.h"
 #include "opentelemetry/sdk/metrics/push_metric_exporter.h"
 
 #ifdef BAZEL_BUILD
@@ -28,7 +28,7 @@
 #  include "metrics_foo_library/foo_library.h"
 #endif
 
-namespace metric_sdk    = opentelemetry::sdk::metrics;
+namespace metrics_sdk   = opentelemetry::sdk::metrics;
 namespace common        = opentelemetry::common;
 namespace metrics_api   = opentelemetry::metrics;
 namespace otlp_exporter = opentelemetry::exporter::otlp;
@@ -46,26 +46,26 @@ void InitMetrics()
   std::string schema{"https://opentelemetry.io/schemas/1.2.0"};
 
   // Initialize and set the global MeterProvider
-  metric_sdk::PeriodicExportingMetricReaderOptions reader_options;
+  metrics_sdk::PeriodicExportingMetricReaderOptions reader_options;
   reader_options.export_interval_millis = std::chrono::milliseconds(1000);
   reader_options.export_timeout_millis  = std::chrono::milliseconds(500);
 
-  auto reader =
-      metric_sdk::PeriodicExportingMetricReaderFactory::Create(std::move(exporter), reader_options);
+  auto reader = metrics_sdk::PeriodicExportingMetricReaderFactory::Create(std::move(exporter),
+                                                                          reader_options);
 
-  auto context = metric_sdk::MeterContextFactory::Create();
+  auto context = metrics_sdk::MeterContextFactory::Create();
   context->AddMetricReader(std::move(reader));
 
-  auto u_provider = metric_sdk::MeterProviderFactory::Create(std::move(context));
+  auto u_provider = metrics_sdk::MeterProviderFactory::Create(std::move(context));
   std::shared_ptr<opentelemetry::metrics::MeterProvider> provider(std::move(u_provider));
 
-  metrics_api::Provider::SetMeterProvider(provider);
+  metrics_sdk::Provider::SetMeterProvider(provider);
 }
 
 void CleanupMetrics()
 {
   std::shared_ptr<metrics_api::MeterProvider> none;
-  metrics_api::Provider::SetMeterProvider(none);
+  metrics_sdk::Provider::SetMeterProvider(none);
 }
 }  // namespace
 
