@@ -24,8 +24,15 @@ namespace otlp
  */
 struct OPENTELEMETRY_EXPORT OtlpGrpcMetricExporterOptions : public OtlpGrpcClientOptions
 {
+  /** Lookup environment variables. */
   OtlpGrpcMetricExporterOptions();
-  ~OtlpGrpcMetricExporterOptions();
+  /** No defaults. */
+  OtlpGrpcMetricExporterOptions(void *);
+  OtlpGrpcMetricExporterOptions(const OtlpGrpcMetricExporterOptions &)            = default;
+  OtlpGrpcMetricExporterOptions(OtlpGrpcMetricExporterOptions &&)                 = default;
+  OtlpGrpcMetricExporterOptions &operator=(const OtlpGrpcMetricExporterOptions &) = default;
+  OtlpGrpcMetricExporterOptions &operator=(OtlpGrpcMetricExporterOptions &&)      = default;
+  ~OtlpGrpcMetricExporterOptions() override;
 
   /** Preferred Aggregation Temporality. */
   PreferredAggregationTemporality aggregation_temporality;
