@@ -4,6 +4,8 @@
 #include "opentelemetry/exporters/otlp/otlp_file_log_record_exporter_factory.h"
 #include "opentelemetry/exporters/otlp/otlp_file_log_record_exporter.h"
 #include "opentelemetry/exporters/otlp/otlp_file_log_record_exporter_options.h"
+#include "opentelemetry/exporters/otlp/otlp_file_log_record_exporter_runtime_options.h"
+#include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace exporter
@@ -20,9 +22,18 @@ OtlpFileLogRecordExporterFactory::Create()
 
 std::unique_ptr<opentelemetry::sdk::logs::LogRecordExporter>
 OtlpFileLogRecordExporterFactory::Create(const OtlpFileLogRecordExporterOptions &options)
+{
+  OtlpFileLogRecordExporterRuntimeOptions runtime_options;
+  return Create(options, runtime_options);
+}
+
+std::unique_ptr<opentelemetry::sdk::logs::LogRecordExporter>
+OtlpFileLogRecordExporterFactory::Create(
+    const OtlpFileLogRecordExporterOptions &options,
+    const OtlpFileLogRecordExporterRuntimeOptions &runtime_options)
 {
   std::unique_ptr<opentelemetry::sdk::logs::LogRecordExporter> exporter(
-      new OtlpFileLogRecordExporter(options));
+      new OtlpFileLogRecordExporter(options, runtime_options));
   return exporter;
 }
 
