@@ -4,8 +4,12 @@
 // MUST be first (absl)
 #include "opentelemetry/exporters/otlp/otlp_grpc_metric_exporter.h"
 
+#include <memory>
+
 #include "opentelemetry/exporters/otlp/otlp_grpc_metric_exporter_factory.h"
 #include "opentelemetry/exporters/otlp/otlp_grpc_metric_exporter_options.h"
+#include "opentelemetry/sdk/metrics/push_metric_exporter.h"
+#include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace exporter
@@ -28,6 +32,15 @@ OtlpGrpcMetricExporterFactory::Create(const OtlpGrpcMetricExporterOptions &optio
   return exporter;
 }
 
+std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter>
+OtlpGrpcMetricExporterFactory::Create(const OtlpGrpcMetricExporterOptions &options,
+                                      const std::shared_ptr<OtlpGrpcClient> &client)
+{
+  std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> exporter(
+      new OtlpGrpcMetricExporter(options, client));
+  return exporter;
+}
+
 }  // namespace otlp
 }  // namespace exporter
 OPENTELEMETRY_END_NAMESPACE
