@@ -83,7 +83,7 @@ struct AttributeConverter
   {
     return OwnedAttributeValue(std::string(v));
   }
-  OwnedAttributeValue operator()(std::string v) { return OwnedAttributeValue(v); }
+  OwnedAttributeValue operator()(std::string v) { return OwnedAttributeValue(std::move(v)); }
   OwnedAttributeValue operator()(const char *v) { return OwnedAttributeValue(std::string(v)); }
   OwnedAttributeValue operator()(nostd::span<const uint8_t> v) { return convertSpan<uint8_t>(v); }
   OwnedAttributeValue operator()(nostd::span<const bool> v) { return convertSpan<bool>(v); }
@@ -100,8 +100,7 @@ struct AttributeConverter
   template <typename T, typename U = T>
   OwnedAttributeValue convertSpan(nostd::span<const U> vals)
   {
-    const std::vector<T> copy(vals.begin(), vals.end());
-    return OwnedAttributeValue(std::move(copy));
+    return OwnedAttributeValue(std::vector<T>(vals.begin(), vals.end()));
   }
 };
 
@@ -171,11 +170,7 @@ public:
   // Construct attribute map and populate with attributes
   AttributeMap(const opentelemetry::common::KeyValueIterable &attributes) : AttributeMap()
   {
-    attributes.ForEachKeyValue(
-        [&](nostd::string_view key, opentelemetry::common::AttributeValue value) noexcept {
-          SetAttribute(key, value);
-          return true;
-        });
+    ConstructFrom(attributes);
   }
 
   // Construct attribute map and populate with optional attributes
@@ -183,11 +178,7 @@ public:
   {
     if (attributes != nullptr)
     {
-      attributes->ForEachKeyValue(
-          [&](nostd::string_view key, opentelemetry::common::AttributeValue value) noexcept {
-            SetAttribute(key, value);
-            return true;
-          });
+      ConstructFrom(*attributes);
     }
   }
 
@@ -203,6 +194,15 @@ public:
     }
   }
 
+  void ConstructFrom(const opentelemetry::common::KeyValueIterable &attributes)
+  {
+    attributes.ForEachKeyValue(
+        [&](nostd::string_view key, const opentelemetry::common::AttributeValue &value) noexcept {
+          SetAttribute(key, value);
+          return true;
+        });
+  }
+
   // Returns a reference to this map
   const std::unordered_map<std::string, OwnedAttributeValue> &GetAttributes() const noexcept
   {
@@ -213,7 +213,7 @@ public:
   void SetAttribute(nostd::string_view key,
                     const opentelemetry::common::AttributeValue &value) noexcept
   {
-    (*this)[std::string(key)] = nostd::visit(converter_, value);
+    (*this)[std::string(key)] = nostd::visit(AttributeConverter(), value);
   }
 
   // Compare the attributes of this map with another KeyValueIterable
@@ -235,7 +235,7 @@ public:
             {
               // Order of arguments is important here. OwnedAttributeValue is first then
               // AttributeValue AttributeEqualToVisitor does not support the reverse order
-              return nostd::visit(equal_to_visitor_, kv.second, value);
+              return nostd::visit(AttributeEqualToVisitor(), kv.second, value);
             }
           }
           return false;
@@ -243,10 +243,6 @@ public:
 
     return is_equal;
   }
-
-private:
-  AttributeConverter converter_;
-  AttributeEqualToVisitor equal_to_visitor_;
 };
 
 /**
@@ -291,11 +287,8 @@ public:
   void SetAttribute(nostd::string_view key,
                     const opentelemetry::common::AttributeValue &value) noexcept
   {
-    (*this)[std::string(key)] = nostd::visit(converter_, value);
+    (*this)[std::string(key)] = nostd::visit(AttributeConverter(), value);
   }
-
-private:
-  AttributeConverter converter_;
 };
 
 }  // namespace common
