@@ -7,6 +7,7 @@
 #include <string>
 
 #include "opentelemetry/sdk/configuration/default_histogram_aggregation.h"
+#include "opentelemetry/sdk/configuration/grpc_tls_configuration.h"
 #include "opentelemetry/sdk/configuration/headers_configuration.h"
 #include "opentelemetry/sdk/configuration/push_metric_exporter_configuration.h"
 #include "opentelemetry/sdk/configuration/push_metric_exporter_configuration_visitor.h"
@@ -30,14 +31,11 @@ public:
   }
 
   std::string endpoint;
-  std::string certificate_file;
-  std::string client_key_file;
-  std::string client_certificate_file;
+  std::unique_ptr<GrpcTlsConfiguration> tls;
   std::unique_ptr<HeadersConfiguration> headers;
   std::string headers_list;
   std::string compression;
   std::size_t timeout{0};
-  bool insecure{false};
   TemporalityPreference temporality_preference{TemporalityPreference::cumulative};
   DefaultHistogramAggregation default_histogram_aggregation{
       DefaultHistogramAggregation::explicit_bucket_histogram};
