@@ -5,6 +5,7 @@
 
 #include <vector>
 
+#include "opentelemetry/sdk/metrics/instruments.h"
 #include "opentelemetry/sdk/metrics/state/attributes_hashmap.h"
 #include "opentelemetry/version.h"
 
@@ -13,6 +14,7 @@ namespace sdk
 {
 namespace metrics
 {
+
 class AggregationConfig
 {
 public:
@@ -20,6 +22,8 @@ public:
       : cardinality_limit_(cardinality_limit)
   {}
 
+  virtual AggregationType GetType() const noexcept { return AggregationType::kDefault; }
+
   static const AggregationConfig *GetOrDefault(const AggregationConfig *config)
   {
     if (config)
@@ -37,6 +41,12 @@ public:
 class HistogramAggregationConfig : public AggregationConfig
 {
 public:
+  HistogramAggregationConfig(size_t cardinality_limit = kAggregationCardinalityLimit)
+      : AggregationConfig(cardinality_limit)
+  {}
+
+  AggregationType GetType() const noexcept override { return AggregationType::kHistogram; }
+
   std::vector<double> boundaries_;
   bool record_min_max_ = true;
 };
@@ -44,6 +54,16 @@ public:
 class Base2ExponentialHistogramAggregationConfig : public AggregationConfig
 {
 public:
+  Base2ExponentialHistogramAggregationConfig(
+      size_t cardinality_limit = kAggregationCardinalityLimit)
+      : AggregationConfig(cardinality_limit)
+  {}
+
+  AggregationType GetType() const noexcept override
+  {
+    return AggregationType::kBase2ExponentialHistogram;
+  }
+
   size_t max_buckets_  = 160;
   int32_t max_scale_   = 20;
   bool record_min_max_ = true;
