@@ -17,22 +17,30 @@ namespace trace
 /**
  * Struct to hold batch SpanProcessor options.
  */
-struct BatchSpanProcessorOptions
+struct OPENTELEMETRY_EXPORT BatchSpanProcessorOptions
 {
+  BatchSpanProcessorOptions();
   /**
    * The maximum buffer/queue size. After the size is reached, spans are
    * dropped.
    */
-  size_t max_queue_size = 2048;
+  size_t max_queue_size;
 
   /* The time interval between two consecutive exports. */
-  std::chrono::milliseconds schedule_delay_millis = std::chrono::milliseconds(5000);
+  std::chrono::milliseconds schedule_delay_millis;
+
+  /**
+   * The maximum time allowed to to export data
+   * It is not currently used by the SDK and the parameter is ignored
+   * TODO: Implement the parameter in BatchSpanProcessor
+   */
+  std::chrono::milliseconds export_timeout;
 
   /**
    * The maximum batch size of every export. It must be smaller or
    * equal to max_queue_size.
    */
-  size_t max_export_batch_size = 512;
+  size_t max_export_batch_size;
 };
 
 }  // namespace trace
