@@ -180,29 +180,31 @@ public:
   void VisitString(
       const opentelemetry::sdk::configuration::StringAttributeValueConfiguration *model) override
   {
-    opentelemetry::common::AttributeValue attribute_value(model->value);
-    resource_attributes_.SetAttribute(name_, attribute_value);
+    opentelemetry::common::AttributeValue attr_value(model->value);
+    resource_attributes_.SetAttribute(name_, attr_value);
   }
 
   void VisitInteger(
       const opentelemetry::sdk::configuration::IntegerAttributeValueConfiguration *model) override
   {
-    opentelemetry::common::AttributeValue attribute_value(model->value);
-    resource_attributes_.SetAttribute(name_, attribute_value);
+    /* Provide exact type to opentelemetry::common::AttributeValue variant. */
+    int64_t value = model->value;
+    opentelemetry::common::AttributeValue attr_value(value);
+    resource_attributes_.SetAttribute(name_, attr_value);
   }
 
   void VisitDouble(
       const opentelemetry::sdk::configuration::DoubleAttributeValueConfiguration *model) override
   {
-    opentelemetry::common::AttributeValue attribute_value(model->value);
-    resource_attributes_.SetAttribute(name_, attribute_value);
+    opentelemetry::common::AttributeValue attr_value(model->value);
+    resource_attributes_.SetAttribute(name_, attr_value);
   }
 
   void VisitBoolean(
       const opentelemetry::sdk::configuration::BooleanAttributeValueConfiguration *model) override
   {
-    opentelemetry::common::AttributeValue attribute_value(model->value);
-    resource_attributes_.SetAttribute(name_, attribute_value);
+    opentelemetry::common::AttributeValue attr_value(model->value);
+    resource_attributes_.SetAttribute(name_, attr_value);
   }
 
   void VisitStringArray(
@@ -222,8 +224,8 @@ public:
 
     nostd::span<const nostd::string_view> span(string_view_array.data(), string_view_array.size());
 
-    opentelemetry::common::AttributeValue attribute_value(span);
-    resource_attributes_.SetAttribute(name_, attribute_value);
+    opentelemetry::common::AttributeValue attr_value(span);
+    resource_attributes_.SetAttribute(name_, attr_value);
   }
 
   void VisitIntegerArray(
@@ -243,8 +245,8 @@ public:
 
     nostd::span<const int64_t> span(int_array.data(), int_array.size());
 
-    opentelemetry::common::AttributeValue attribute_value(span);
-    resource_attributes_.SetAttribute(name_, attribute_value);
+    opentelemetry::common::AttributeValue attr_value(span);
+    resource_attributes_.SetAttribute(name_, attr_value);
   }
 
   void VisitDoubleArray(
@@ -257,8 +259,8 @@ public:
 
     nostd::span<const double> span(model->value.data(), model->value.size());
 
-    opentelemetry::common::AttributeValue attribute_value(span);
-    resource_attributes_.SetAttribute(name_, attribute_value);
+    opentelemetry::common::AttributeValue attr_value(span);
+    resource_attributes_.SetAttribute(name_, attr_value);
   }
 
   void VisitBooleanArray(
@@ -281,8 +283,8 @@ public:
 
     nostd::span<const bool> span(&bool_array[0], length);
 
-    opentelemetry::common::AttributeValue attribute_value(span);
-    resource_attributes_.SetAttribute(name_, attribute_value);
+    opentelemetry::common::AttributeValue attr_value(span);
+    resource_attributes_.SetAttribute(name_, attr_value);
   }
 
   opentelemetry::common::AttributeValue attribute_value;
@@ -709,12 +711,8 @@ std::unique_ptr<opentelemetry::sdk::trace::Sampler> SdkBuilder::CreateAlwaysOnSa
 std::unique_ptr<opentelemetry::sdk::trace::Sampler> SdkBuilder::CreateJaegerRemoteSampler(
     const opentelemetry::sdk::configuration::JaegerRemoteSamplerConfiguration * /* model */) const
 {
-  std::unique_ptr<opentelemetry::sdk::trace::Sampler> sdk;
-
   static const std::string die("JaegerRemoteSampler not supported");
   throw UnsupportedException(die);
-
-  return sdk;
 }
 
 std::unique_ptr<opentelemetry::sdk::trace::Sampler> SdkBuilder::CreateParentBasedSampler(
@@ -827,9 +825,7 @@ std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> SdkBuilder::CreateOtlpH
     const opentelemetry::sdk::configuration::OtlpHttpSpanExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> sdk;
-  const OtlpHttpSpanExporterBuilder *builder;
-
-  builder = registry_->GetOtlpHttpSpanBuilder();
+  const OtlpHttpSpanExporterBuilder *builder = registry_->GetOtlpHttpSpanBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpHttpSpanExporter() using registered http builder");
@@ -845,9 +841,7 @@ std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> SdkBuilder::CreateOtlpG
     const opentelemetry::sdk::configuration::OtlpGrpcSpanExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> sdk;
-  const OtlpGrpcSpanExporterBuilder *builder;
-
-  builder = registry_->GetOtlpGrpcSpanBuilder();
+  const OtlpGrpcSpanExporterBuilder *builder = registry_->GetOtlpGrpcSpanBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpGrpcSpanExporter() using registered grpc builder");
@@ -863,9 +857,7 @@ std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> SdkBuilder::CreateOtlpF
     const opentelemetry::sdk::configuration::OtlpFileSpanExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::trace::SpanExporter> sdk;
-  const OtlpFileSpanExporterBuilder *builder;
-
-  builder = registry_->GetOtlpFileSpanBuilder();
+  const OtlpFileSpanExporterBuilder *builder = registry_->GetOtlpFileSpanBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpFileSpanExporter() using registered file builder");
@@ -1149,11 +1141,11 @@ SdkBuilder::CreatePropagator(
 static opentelemetry::sdk::metrics::InstrumentType ConvertInstrumentType(
     enum opentelemetry::sdk::configuration::InstrumentType config)
 {
-  opentelemetry::sdk::metrics::InstrumentType sdk;
+  opentelemetry::sdk::metrics::InstrumentType sdk{
+      opentelemetry::sdk::metrics::InstrumentType::kCounter};
 
   switch (config)
   {
-    case opentelemetry::sdk::configuration::InstrumentType::none:
     case opentelemetry::sdk::configuration::InstrumentType::counter:
       sdk = opentelemetry::sdk::metrics::InstrumentType::kCounter;
       break;
@@ -1172,6 +1164,10 @@ static opentelemetry::sdk::metrics::InstrumentType ConvertInstrumentType(
     case opentelemetry::sdk::configuration::InstrumentType::up_down_counter:
       sdk = opentelemetry::sdk::metrics::InstrumentType::kUpDownCounter;
       break;
+    case opentelemetry::sdk::configuration::InstrumentType::none:
+    default:
+      sdk = opentelemetry::sdk::metrics::InstrumentType::kCounter;
+      break;
   }
 
   return sdk;
@@ -1182,9 +1178,8 @@ SdkBuilder::CreateOtlpHttpPushMetricExporter(
     const opentelemetry::sdk::configuration::OtlpHttpPushMetricExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> sdk;
-  const OtlpHttpPushMetricExporterBuilder *builder;
-
-  builder = registry_->GetOtlpHttpPushMetricExporterBuilder();
+  const OtlpHttpPushMetricExporterBuilder *builder =
+      registry_->GetOtlpHttpPushMetricExporterBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpHttpPushMetricExporter() using registered http builder");
@@ -1201,9 +1196,8 @@ SdkBuilder::CreateOtlpGrpcPushMetricExporter(
     const opentelemetry::sdk::configuration::OtlpGrpcPushMetricExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> sdk;
-  const OtlpGrpcPushMetricExporterBuilder *builder;
-
-  builder = registry_->GetOtlpGrpcPushMetricExporterBuilder();
+  const OtlpGrpcPushMetricExporterBuilder *builder =
+      registry_->GetOtlpGrpcPushMetricExporterBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpGrpcPushMetricExporter() using registered grpc builder");
@@ -1220,9 +1214,8 @@ SdkBuilder::CreateOtlpFilePushMetricExporter(
     const opentelemetry::sdk::configuration::OtlpFilePushMetricExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::metrics::PushMetricExporter> sdk;
-  const OtlpFilePushMetricExporterBuilder *builder;
-
-  builder = registry_->GetOtlpFilePushMetricExporterBuilder();
+  const OtlpFilePushMetricExporterBuilder *builder =
+      registry_->GetOtlpFilePushMetricExporterBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpFilePushMetricExporter() using registered file builder");
@@ -1531,9 +1524,7 @@ SdkBuilder::CreateOtlpHttpLogRecordExporter(
     const opentelemetry::sdk::configuration::OtlpHttpLogRecordExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::logs::LogRecordExporter> sdk;
-  const OtlpHttpLogRecordExporterBuilder *builder;
-
-  builder = registry_->GetOtlpHttpLogRecordBuilder();
+  const OtlpHttpLogRecordExporterBuilder *builder = registry_->GetOtlpHttpLogRecordBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpHttpLogRecordExporter() using registered http builder");
@@ -1550,9 +1541,7 @@ SdkBuilder::CreateOtlpGrpcLogRecordExporter(
     const opentelemetry::sdk::configuration::OtlpGrpcLogRecordExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::logs::LogRecordExporter> sdk;
-  const OtlpGrpcLogRecordExporterBuilder *builder;
-
-  builder = registry_->GetOtlpGrpcLogRecordBuilder();
+  const OtlpGrpcLogRecordExporterBuilder *builder = registry_->GetOtlpGrpcLogRecordBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpGrpcLogRecordExporter() using registered grpc builder");
@@ -1569,9 +1558,7 @@ SdkBuilder::CreateOtlpFileLogRecordExporter(
     const opentelemetry::sdk::configuration::OtlpFileLogRecordExporterConfiguration *model) const
 {
   std::unique_ptr<opentelemetry::sdk::logs::LogRecordExporter> sdk;
-  const OtlpFileLogRecordExporterBuilder *builder;
-
-  builder = registry_->GetOtlpFileLogRecordBuilder();
+  const OtlpFileLogRecordExporterBuilder *builder = registry_->GetOtlpFileLogRecordBuilder();
   if (builder != nullptr)
   {
     OTEL_INTERNAL_LOG_DEBUG("CreateOtlpFileLogRecordExporter() using registered file builder");
