@@ -9,7 +9,9 @@
 
 #include "opentelemetry/sdk/configuration/batch_span_processor_configuration.h"
 #include "opentelemetry/sdk/configuration/configuration.h"
+#include "opentelemetry/sdk/configuration/grpc_tls_configuration.h"
 #include "opentelemetry/sdk/configuration/headers_configuration.h"
+#include "opentelemetry/sdk/configuration/http_tls_configuration.h"
 #include "opentelemetry/sdk/configuration/jaeger_remote_sampler_configuration.h"
 #include "opentelemetry/sdk/configuration/otlp_file_span_exporter_configuration.h"
 #include "opentelemetry/sdk/configuration/otlp_grpc_span_exporter_configuration.h"
@@ -34,7 +36,7 @@ static std::unique_ptr<opentelemetry::sdk::configuration::Configuration> DoParse
 TEST(YamlTrace, no_processors)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
 )";
 
@@ -45,7 +47,7 @@ tracer_provider:
 TEST(YamlTrace, empty_processors)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
 )";
@@ -57,7 +59,7 @@ tracer_provider:
 TEST(YamlTrace, many_processors)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -77,7 +79,7 @@ tracer_provider:
 TEST(YamlTrace, simple_processor)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -102,7 +104,7 @@ tracer_provider:
 TEST(YamlTrace, default_batch_processor)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - batch:
@@ -131,7 +133,7 @@ tracer_provider:
 TEST(YamlTrace, batch_processor)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - batch:
@@ -164,7 +166,7 @@ tracer_provider:
 TEST(YamlTrace, default_otlp_http)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -189,9 +191,7 @@ tracer_provider:
       reinterpret_cast<opentelemetry::sdk::configuration::OtlpHttpSpanExporterConfiguration *>(
           exporter);
   ASSERT_EQ(otlp_http->endpoint, "somewhere");
-  ASSERT_EQ(otlp_http->certificate_file, "");
-  ASSERT_EQ(otlp_http->client_key_file, "");
-  ASSERT_EQ(otlp_http->client_certificate_file, "");
+  ASSERT_EQ(otlp_http->tls, nullptr);
   ASSERT_EQ(otlp_http->headers, nullptr);
   ASSERT_EQ(otlp_http->headers_list, "");
   ASSERT_EQ(otlp_http->compression, "");
@@ -202,16 +202,17 @@ tracer_provider:
 TEST(YamlTrace, otlp_http)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
         exporter:
           otlp_http:
             endpoint: "somewhere"
-            certificate_file: "certificate_file"
-            client_key_file: "client_key_file"
-            client_certificate_file: "client_certificate_file"
+            tls:
+              certificate_file: "certificate_file"
+              client_key_file: "client_key_file"
+              client_certificate_file: "client_certificate_file"
             headers:
               - name: foo
                 value: "123"
@@ -239,9 +240,10 @@ tracer_provider:
       reinterpret_cast<opentelemetry::sdk::configuration::OtlpHttpSpanExporterConfiguration *>(
           exporter);
   ASSERT_EQ(otlp_http->endpoint, "somewhere");
-  ASSERT_EQ(otlp_http->certificate_file, "certificate_file");
-  ASSERT_EQ(otlp_http->client_key_file, "client_key_file");
-  ASSERT_EQ(otlp_http->client_certificate_file, "client_certificate_file");
+  ASSERT_NE(otlp_http->tls, nullptr);
+  ASSERT_EQ(otlp_http->tls->certificate_file, "certificate_file");
+  ASSERT_EQ(otlp_http->tls->client_key_file, "client_key_file");
+  ASSERT_EQ(otlp_http->tls->client_certificate_file, "client_certificate_file");
   ASSERT_NE(otlp_http->headers, nullptr);
   ASSERT_EQ(otlp_http->headers->kv_map.size(), 2);
   ASSERT_EQ(otlp_http->headers->kv_map["foo"], "123");
@@ -255,7 +257,7 @@ tracer_provider:
 TEST(YamlTrace, default_otlp_grpc)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -280,29 +282,28 @@ tracer_provider:
       reinterpret_cast<opentelemetry::sdk::configuration::OtlpGrpcSpanExporterConfiguration *>(
           exporter);
   ASSERT_EQ(otlp_grpc->endpoint, "somewhere");
-  ASSERT_EQ(otlp_grpc->certificate_file, "");
-  ASSERT_EQ(otlp_grpc->client_key_file, "");
-  ASSERT_EQ(otlp_grpc->client_certificate_file, "");
+  ASSERT_EQ(otlp_grpc->tls, nullptr);
   ASSERT_EQ(otlp_grpc->headers, nullptr);
   ASSERT_EQ(otlp_grpc->headers_list, "");
   ASSERT_EQ(otlp_grpc->compression, "");
   ASSERT_EQ(otlp_grpc->timeout, 10000);
-  ASSERT_EQ(otlp_grpc->insecure, false);
 }
 
 TEST(YamlTrace, otlp_grpc)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
         exporter:
           otlp_grpc:
             endpoint: "somewhere"
-            certificate_file: "certificate_file"
-            client_key_file: "client_key_file"
-            client_certificate_file: "client_certificate_file"
+            tls:
+              certificate_file: "certificate_file"
+              client_key_file: "client_key_file"
+              client_certificate_file: "client_certificate_file"
+              insecure: true
             headers:
               - name: foo
                 value: "123"
@@ -311,7 +312,6 @@ tracer_provider:
             headers_list: "baz=789"
             compression: "compression"
             timeout: 5000
-            insecure: true
 )";
 
   auto config = DoParse(yaml);
@@ -330,9 +330,11 @@ tracer_provider:
       reinterpret_cast<opentelemetry::sdk::configuration::OtlpGrpcSpanExporterConfiguration *>(
           exporter);
   ASSERT_EQ(otlp_grpc->endpoint, "somewhere");
-  ASSERT_EQ(otlp_grpc->certificate_file, "certificate_file");
-  ASSERT_EQ(otlp_grpc->client_key_file, "client_key_file");
-  ASSERT_EQ(otlp_grpc->client_certificate_file, "client_certificate_file");
+  ASSERT_NE(otlp_grpc->tls, nullptr);
+  ASSERT_EQ(otlp_grpc->tls->certificate_file, "certificate_file");
+  ASSERT_EQ(otlp_grpc->tls->client_key_file, "client_key_file");
+  ASSERT_EQ(otlp_grpc->tls->client_certificate_file, "client_certificate_file");
+  ASSERT_EQ(otlp_grpc->tls->insecure, true);
   ASSERT_NE(otlp_grpc->headers, nullptr);
   ASSERT_EQ(otlp_grpc->headers->kv_map.size(), 2);
   ASSERT_EQ(otlp_grpc->headers->kv_map["foo"], "123");
@@ -340,13 +342,12 @@ tracer_provider:
   ASSERT_EQ(otlp_grpc->headers_list, "baz=789");
   ASSERT_EQ(otlp_grpc->compression, "compression");
   ASSERT_EQ(otlp_grpc->timeout, 5000);
-  ASSERT_EQ(otlp_grpc->insecure, true);
 }
 
 TEST(YamlTrace, default_otlp_file)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -375,7 +376,7 @@ tracer_provider:
 TEST(YamlTrace, otlp_file)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -405,7 +406,7 @@ tracer_provider:
 TEST(YamlTrace, otlp_console)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -430,7 +431,7 @@ tracer_provider:
 TEST(YamlTrace, default_otlp_zipkin)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -461,7 +462,7 @@ tracer_provider:
 TEST(YamlTrace, otlp_zipkin)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -493,7 +494,7 @@ tracer_provider:
 TEST(YamlTrace, no_limits)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -510,7 +511,7 @@ tracer_provider:
 TEST(YamlTrace, default_limits)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -534,7 +535,7 @@ tracer_provider:
 TEST(YamlTrace, limits)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -564,7 +565,7 @@ tracer_provider:
 TEST(YamlTrace, no_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -581,7 +582,7 @@ tracer_provider:
 TEST(YamlTrace, empty_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -597,7 +598,7 @@ tracer_provider:
 TEST(YamlTrace, many_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -615,7 +616,7 @@ tracer_provider:
 TEST(YamlTrace, always_off_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -634,7 +635,7 @@ tracer_provider:
 TEST(YamlTrace, always_on_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -653,7 +654,7 @@ tracer_provider:
 TEST(YamlTrace, jaeger_remote_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -683,7 +684,7 @@ tracer_provider:
 TEST(YamlTrace, default_parent_based_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -711,7 +712,7 @@ tracer_provider:
 TEST(YamlTrace, parent_based_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -749,7 +750,7 @@ tracer_provider:
 TEST(YamlTrace, default_trace_id_ratio_based_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
@@ -773,7 +774,7 @@ tracer_provider:
 TEST(YamlTrace, trace_id_ratio_based_sampler)
 {
   std::string yaml = R"(
-file_format: xx.yy
+file_format: "1.0-trace"
 tracer_provider:
   processors:
     - simple:
