@@ -3,8 +3,17 @@
 
 #ifdef ENABLE_METRICS_EXEMPLAR_PREVIEW
 
-#  include "opentelemetry/sdk/metrics/exemplar/no_exemplar_reservoir.h"
 #  include <gtest/gtest.h>
+#  include <stdint.h>
+#  include <chrono>
+#  include <memory>
+#  include <string>
+#  include <vector>
+
+#  include "opentelemetry/common/timestamp.h"
+#  include "opentelemetry/context/context.h"
+#  include "opentelemetry/sdk/metrics/data/exemplar_data.h"
+#  include "opentelemetry/sdk/metrics/exemplar/reservoir.h"
 
 using namespace opentelemetry::sdk::metrics;
 
